@@ -1,4 +1,4 @@
-from dynamofl.api.DatasourceAPI import DatasourceAPI
+from .api.DatasourceAPI import DatasourceAPI
 
 
 class _Datasource:
