@@ -8,7 +8,7 @@ import pathlib
 import zipfile
 import queue
 
-from dynamofl.api.ProjectAPI import ProjectAPI
+from .api.ProjectAPI import ProjectAPI
 
 from .State import _State
 from .Request import _check_for_error
