@@ -20,7 +20,7 @@ class _Request:
     def _get_headers(self):
         return {'Authorization': f'Bearer {self.token}'}
 
-    def _make_request(self, method, url, params=None, files=None, list=False, print_error=True):
+    def _make_request(self, method, url, params=None, files=None, list=False, throw_error=True, print_error=True):
         if method == 'POST':
             r = requests.post(
                 f'{self._get_route()}{url}',
@@ -42,7 +42,10 @@ class _Request:
             )
 
         if print_error:
-            _check_for_error(r)
+            if not r.ok:
+                print(json.dumps(json.loads(r.text), indent=4))
+        if throw_error:
+            r.raise_for_status()
 
         if r.content:
             if list:
