@@ -54,7 +54,10 @@ class _State:
             # on some project round completed
             # get appropriate train, test methods
 
-            if trainer_key not in self.datasources[datasource_key].trainers and not project_info['hasDynamicTrainer']:
+            if (
+                datasource_key not in self.datasources or
+                (trainer_key not in self.datasources[datasource_key].trainers and not project_info['hasDynamicTrainer'])
+            ):
                 return
 
             if project_info['hasDynamicTrainer']:
@@ -105,8 +108,12 @@ class _State:
             # on some project round completed
             # get appropriate train, test methods
 
-            if trainer_key not in self.datasources[datasource_key].trainers and not project_info['hasDynamicTrainer']:
+            if (
+                datasource_key not in self.datasources or
+                (trainer_key not in self.datasources[datasource_key].trainers and not project_info['hasDynamicTrainer'])
+            ):
                 return
+
             if project_info['hasDynamicTrainer']:
                 mod = import_module(f'dynamic_trainers.{project_key}.train')
                 train = getattr(mod, 'train')
@@ -158,13 +165,10 @@ class _State:
             # Valid types are 'label' and 'feature'
             params['type'] = type
 
-        try:
-            # Datasource exists so update it
-            self.datasource_api.connect_datasource(key, params)
+        res = self.datasource_api.put_datasource(key, params)
+        if res:
             print(f'>>> Updated datasource "{key}"')
-        except:
-            # Datasource doesn't exist so create it
-            self.datasource_api.create_datasource(params=params)
+        else:
             print(f'>>> Created datasource "{key}"')
 
         ds = _Datasource(key, type, api=self.datasource_api)
