@@ -21,3 +21,18 @@ class DatasourceAPI:
 
     def create_trainers(self, key, params):
         return self.request._make_request('POST', f'/datasources/{key}/trainers', params=params)
+
+    def put_datasource(self, key, params):
+        '''
+        Returns True if ds existed and was updated
+
+        Returns False if ds did not exist and was created
+        '''
+        try:
+            # Datasource exists so update it
+            self.request._make_request('POST', f'/datasources/{key}', params=params, print_error=False)
+            return True
+        except:
+            # Datasource doesn't exist so create it
+            self.create_datasource(params=params)
+            return False
\ No newline at end of file
