@@ -1,16 +1,15 @@
-from .State import _State
+from .Helpers import Helpers
 from .MessageHandler import _MessageHandler
-from .Helpers import _Helpers
+from .State import _State
+
+RETRY_AFTER = 5  # seconds
 
-RETRY_AFTER = 5 # seconds
 
 class DynamoFL():
-    def __init__(self, token, host='https://api.dynamofl.com', metadata=None):
+    def __init__(self, token: str, host: str = 'https://api.dynamofl.com', metadata: object = None):
         self._state = _State(token, host, metadata)
 
-        self._helpers = _Helpers()
-
-        self._messagehandler = _MessageHandler(self._state, token, host)
+        self._messagehandler = _MessageHandler(self._state)
         self._messagehandler.connect_to_ws()
 
     def attach_datasource(self, key, name=None, metadata=None, type=None):
@@ -35,18 +34,12 @@ class DynamoFL():
         return self._state.get_project(project_key)
 
     def get_projects(self):
-        return self._state.get_project()
-    
-    def load_state_dict_tensorflow(self, model):
-        return self._helpers.load_state_dict_tensorflow(model)
-    
-    def save_state_dict_tensorflow(self, model, state_dict):
-        return self._helpers.save_state_dict_tensorflow(model, state_dict)
+        return self._state.get_projects()
 
     def is_datasource_labeled(self, project_key=None, datasource_key=None):
         '''
         Accepts a valid datasource_key and project_key
         Returns True if the datasource is labeled for the project; False otherwise
-        
+
         '''
         return self._state.is_datasource_labeled(project_key=project_key, datasource_key=datasource_key)
